from win32com.client import dynamic

def EnsureDispatch(
    prog_id: str | dynamic.PyIDispatchType | dynamic._GoodDispatchTypes | dynamic.PyIUnknownType, bForDemand: int = ...
) -> dynamic.CDispatch: ...
