from win32.lib.pywintypes import error as error

def GetHandle(*args, **kwargs): ...  # incomplete
def GetTracer(*args, **kwargs): ...  # incomplete
def InitRead(*args, **kwargs): ...  # incomplete
def InitWrite(*args, **kwargs): ...  # incomplete
def TermRead(*args, **kwargs): ...  # incomplete
def TermWrite(*args, **kwargs): ...  # incomplete
def blockingread(*args, **kwargs): ...  # incomplete
def flush(*args, **kwargs): ...  # incomplete
def read(*args, **kwargs): ...  # incomplete
def setprint(*args, **kwargs): ...  # incomplete
def write(*args, **kwargs): ...  # incomplete
