from _typeshed import Incomplete

import _win32typing

def CeRapiInit() -> None: ...
def CeRapiUninit() -> None: ...
def CreateProcess(
    __appName: str | None,
    __commandLine: str,
    __processAttributes: _win32typing.PySECURITY_ATTRIBUTES | None,
    __threadAttributes: _win32typing.PySECURITY_ATTRIBUTES | None,
    __bInheritHandles: int | bool,
    __dwCreationFlags: int,
    __newEnvironment: dict[str, str] | None,
    __currentDirectory: str | None,
    __startupinfo: _win32typing.PySTARTUPINFO,
) -> tuple[int, int, Incomplete, Incomplete]: ...
def CeRapiInitEx(): ...
def CeCopyFile(_from: str, to: str, bFailIfExists) -> None: ...
def CeCheckPassword(password: str) -> None: ...
def CeCreateFile(
    fileName: str,
    desiredAccess,
    shareMode,
    attributes: _win32typing.PySECURITY_ATTRIBUTES,
    creationDisposition,
    flagsAndAttributes,
    hTemplateFile: int,
) -> _win32typing.PyCEHANDLE: ...
def CeDeleteFile(fileName: str) -> None: ...
def CeMoveFile(existingFileName: str, newFileName: str) -> None: ...
def CeCreateDirectory(name: str, sa: _win32typing.PySECURITY_ATTRIBUTES) -> None: ...
def CeRemoveDirectory(lpPathName: str) -> None: ...
def CeGetTempPath() -> str: ...
def CeGetSystemInfo(): ...
def CeGetDesktopDeviceCaps(): ...
def CeGetSystemMetrics(): ...
def CeGetSpecialFolderPath() -> str: ...
def CeGetStoreInformation() -> tuple[Incomplete, Incomplete]: ...
def CeGetSystemPowerStatusEx(): ...
def CeSHCreateShortcut() -> None: ...
def CeSHGetShortcutTarget(): ...
def CeGetVersionEx() -> tuple[Incomplete, Incomplete, Incomplete, Incomplete, str]: ...
def CeGlobalMemoryStatus(): ...
def FindFiles(fileSpec: str): ...
def CeGetFileAttributes(fileName: str): ...
def CeSetFileAttributes(filename: str, newAttributes) -> None: ...
def CeGetFileSize(): ...
def CeReadFile(hFile: int, bufSize) -> str: ...
def WriteFile(__hFile: int, __data: str | bytes | _win32typing.PyOVERLAPPEDReadBuffer) -> tuple[int, int]: ...

CSIDL_BITBUCKET = ...
CSIDL_COMMON_DESKTOPDIRECTORY = ...
CSIDL_COMMON_PROGRAMS = ...
CSIDL_COMMON_STARTMENU = ...
CSIDL_COMMON_STARTUP = ...
CSIDL_CONTROLS = ...
CSIDL_DESKTOP = ...
CSIDL_DESKTOPDIRECTORY = ...
CSIDL_DRIVES = ...
CSIDL_FONTS = ...
CSIDL_NETHOOD = ...
CSIDL_NETWORK = ...
CSIDL_PERSONAL = ...
CSIDL_PRINTERS = ...
CSIDL_PROGRAMS = ...
CSIDL_RECENT = ...
CSIDL_SENDTO = ...
CSIDL_STARTMENU = ...
CSIDL_STARTUP = ...
CSIDL_TEMPLATES = ...
