# Necessary for mypy to not fail with:
# 'error: Cannot find implementation or library stub for module named "win32comext.axscript.client.pyscript"'
# in: .gateways, .stackframe, .expressions, .adb, .contexts, .codecontainer, .documents, .debugger
